@@ -29,38 +29,31 @@ FEATURE_NAMES = {
     "ch-width",
     "clipboard-read",
     "clipboard-write",
+    "conversion-measurement",
     "cross-origin-isolated",
+    "display-capture",
     "document-domain",
-    "document-write",
-    "downloads",
     "encrypted-media",
     "execution-while-not-rendered",
     "execution-while-out-of-viewport",
     "focus-without-user-activation",
-    "forms",
     "fullscreen",
     "gamepad",
     "geolocation",
     "gyroscope",
     "hid",
     "idle-detection",
+    "interest-cohort",
     "magnetometer",
     "microphone",
     "midi",
-    "modals",
-    "orientation-lock",
+    "otp-credentials",
     "payment",
     "picture-in-picture",
-    "pointer-lock",
-    "popups",
-    "presentation",
     "publickey-credentials-get",
     "screen-wake-lock",
-    "scripts",
     "serial",
-    "sync-script",
     "sync-xhr",
-    "top-navigation",
     "usb",
     "vertical-scroll",
     "xr-spatial-tracking",
@@ -68,7 +61,6 @@ FEATURE_NAMES = {
     # Retrieved from Firefox document.featurePolicy.allowedFeatures()
     # with dom.security.featurePolicy.header.enabled preference set to true
     # in about:config (plus a restart):
-    "display-capture",
     "speaker",
     "vr",
     "web-share",
